@@ -566,7 +566,7 @@ void Request::post(bool authRequired) {
     case QVariant::String:
     case QVariant::ByteArray:
     case QVariant::Invalid:
-        data = d->data.toByteArray();
+        data = d->data.toString().toUtf8();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
@@ -613,7 +613,7 @@ void Request::put(bool authRequired) {
     case QVariant::String:
     case QVariant::ByteArray:
     case QVariant::Invalid:
-        data = d->data.toByteArray();
+        data = d->data.toString().toUtf8();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
@@ -660,7 +660,7 @@ void Request::patch(bool authRequired) {
     case QVariant::String:
     case QVariant::ByteArray:
     case QVariant::Invalid:
-        data = d->data.toByteArray();
+        data = d->data.toString().toUtf8();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
